@@ -129,6 +129,59 @@ impl<R: buffered_reader::BufferedReader<()>> Deserializer<R> {
 		}
 	}
 
+	fn peek_line(&mut self) -> Result<&str, DeserializeError> {
+		let mut b = self.input.read_to(b'\n')?;
+		let mut line_start = b.len();
+
+		if let Some(comment_start) = b.iter().position(|c| c == &b'#') {
+			b = &b[..comment_start];
+		}
+
+		let s = crate::from_utf8(b, self.location)?;
+		let mut content = s.trim();
+
+		if !content.is_empty() {
+			let content_ptr = content.as_ptr();
+			let content_len = content.len();
+			let d = self.input.buffer();
+			let d = &d[content_ptr as usize - d.as_ptr() as usize..][..content_len];
+			return Ok(unsafe { crate::from_utf8_unchecked(d) })
+		}
+
+		let root_indent = self.indent.as_ref().map(|s| s.as_str()).unwrap_or("");
+
+		let mut offset = line_start;
+		let mut content_start = 0;
+		let mut location = self.location;
+
+		loop {
+			b = self.input.data(offset + 1)?;
+			for (i, i_end, c) in bstr::ByteSlice::char_indices(&b[offset..]) {
+				if content_start != 0 && c.is_whitespace() {
+					let d = &self.input.buffer()[content_start..offset+i];
+					return Ok(unsafe { crate::from_utf8_unchecked(d) })
+				} else if c == '\n' {
+					line_start = offset + i_end;
+					location.add_lines(1);
+					continue
+				} else if c == std::char::REPLACEMENT_CHARACTER {
+					crate::from_utf8(&b[i..], self.location)?;
+					unreachable!();
+				} else if content_start == 0 && !c.is_whitespace() {
+					let indent = &b[line_start..offset+i];
+					if !(indent.len() > root_indent.len() && indent.starts_with(root_indent.as_bytes())) {
+						return Ok("")
+					}
+					content_start = offset + i;
+				}
+
+				location.add_columns(1);
+			}
+
+			offset += b.len();
+		}
+	}
+
 	fn parse_num(&mut self) -> Result<(Number, crate::Location, std::borrow::Cow<str>), DeserializeError> {
 		let (s, location) = self.parse_string()?;
 		let n = parse_num(&s, location)?;
@@ -255,67 +308,22 @@ impl<'d, R: buffered_reader::BufferedReader<()>> serde::de::Deserializer<'d> for
 	}
 
 	fn deserialize_option<V: serde::de::Visitor<'d>>(self, visitor: V) -> Result<V::Value, DeserializeError> {
-		// This scans looking for a "none". It is hacky and duplicates a lot of code from regular string parsing. However it isn't clear how to reuse the original code. It would both be less efficient (as it has to buffer entire strings) and harder to understand (as it can consume irrelevant data and forget about it). On the bright side this code only handles single-line strings so it can be much simpler.
-
-		let mut b = self.input.read_to(b'\n')?;
-		let mut line_start = b.len();
-
-		if let Some(comment_start) = b.iter().position(|c| c == &b'#') {
-			b = &b[..comment_start];
-		}
-
-		let s = crate::from_utf8(b, self.location)?;
-		let mut content = s.trim();
-
-		let root_indent = self.indent.as_ref().map(|s| s.as_str()).unwrap_or("");
-
-		if !content.is_empty() {
-			return match content {
-				"none" => {
-					self.input.consume(line_start);
-					visitor.visit_none()
+		match self.peek_line()? {
+			"none" => {
+				// TODO: Fix peek_line to avoid this possibility.
+				let (mut s, location) = dbg!(self.parse_string())?;
+				let s = if let Some(comment_start) = s.bytes().position(|c| c == b'#') {
+					&s[..comment_start]
+				} else {
+					&s
+				};
+				if s.trim() != "none" {
+					return Err(crate::DeserializeErrorKind::Unimplemented("Multi line string starting with \"none\" as an option value.").at(location))
 				}
-				_ => visitor.visit_some(self), // TODO: Don't consume.
+				visitor.visit_none()
 			}
+			_ => visitor.visit_some(self), // TODO: Don't consume.
 		}
-
-		let mut offset = line_start;
-		let mut content_start = 0;
-		let mut location = self.location;
-
-		loop {
-			b = self.input.data(offset + 1)?;
-			for (i, i_end, c) in bstr::ByteSlice::char_indices(&b[offset..]) {
-				if content_start != 0 && c.is_whitespace() {
-					content = unsafe { crate::from_utf8_unchecked(&b[content_start..offset+i]) };
-					return match content {
-						"none" => {
-							self.input.consume(offset + i_end);
-							visitor.visit_none()
-						}
-						_ => visitor.visit_some(self), // TODO: Don't consume.
-					}
-				} else if c == '\n' {
-					line_start = offset + i_end;
-					location.add_lines(1);
-					continue
-				} else if c == std::char::REPLACEMENT_CHARACTER {
-					crate::from_utf8(&b[i..], self.location)?;
-					unreachable!();
-				} else if content_start == 0 && !c.is_whitespace() {
-					let indent = &b[line_start..offset+i];
-					if !(indent.len() > root_indent.len() && indent.starts_with(root_indent.as_bytes())) {
-						return visitor.visit_some(self)
-					}
-					content_start = offset + i;
-				}
-
-				location.add_columns(1);
-			}
-
-			offset += b.len();
-		}
-
 	}
 
 	fn deserialize_unit<V: serde::de::Visitor<'d>>(self, visitor: V) -> Result<V::Value, DeserializeError> {
