@@ -14,10 +14,12 @@ impl<'d, 'a, T: buffered_reader::BufferedReader<()>> serde::de::SeqAccess<'d> fo
 			if let Some((_i, i_end, c)) = bstr::ByteSlice::char_indices(&b[indent_end..]).next() {
 				if c == '\n' {
 					self.root.input.consume(indent_end + i_end);
+					self.root.location.add_lines(1);
 					return self.next_element_seed(seed)
 				} else if c == '#' {
 					self.root.input.consume(indent_end + i_end);
 					self.root.input.drop_through(b"\n", true)?;
+					self.root.location.add_lines(1);
 					return self.next_element_seed(seed)
 				} else if c.is_whitespace() {
 					indent_end += i_end;
@@ -49,7 +51,9 @@ impl<'d, 'a, T: buffered_reader::BufferedReader<()>> serde::de::SeqAccess<'d> fo
 				root.push_str(&indent[root.len()..]);
 				self.first = false;
 			} else {
-				return Err(crate::DeserializeError::Invalid(format!("Unmatched indent, was {:?} now {:?}", self.root.indent, indent)))
+				return Err(crate::DeserializeErrorKind::Invalid(
+					format!("Unmatched indent, was {:?} now {:?}", self.root.indent, indent))
+					.at(self.root.location))
 			}
 		} else {
 			self.root.indent = Some(indent.into());
@@ -57,22 +61,27 @@ impl<'d, 'a, T: buffered_reader::BufferedReader<()>> serde::de::SeqAccess<'d> fo
 		}
 
 		self.root.input.consume(indent_end);
+		self.root.location.add_columns(indent_end);
 
 		// A `:` in a list introduces a multi-line block. We simply leave the input stream at the newline after the `:`. The main Deserializer treats this as opening a multi-line block.
 		if self.root.input.data(1)?[0] == b':' {
 			self.root.input.consume(1);
+			self.root.location.add_columns(1);
 			let trailing = self.root.input.read_to(b'\n')?;
 			let mut trailing_len = trailing.len();
 			if trailing.ends_with(b"\n") {
 				trailing_len -= 1;
 			}
-			let s = std::str::from_utf8(trailing)?;
+			let s = crate::from_utf8(trailing, self.root.location)?;
 			if let Some(i) = s.find(|c: char| !c.is_whitespace()) {
 				if s.as_bytes()[i] != b'#' {
-					return Err(crate::DeserializeError::Invalid(format!("Expected newline after `:` found {:?}", s)))
+					return Err(crate::DeserializeErrorKind::Invalid(
+						format!("Expected newline after `:` found {:?}", s))
+						.at(self.root.location))
 				}
 			}
 			self.root.input.consume(trailing_len);
+			self.root.location.add_lines(1);
 			return seed.deserialize(&mut *self.root).map(Some)
 		}
 
